@@ -1,4 +1,4 @@
-# Copyright 2015-2017 Google Inc. All Rights Reserved.
+# Copyright 2015 Google Inc. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -38,7 +38,7 @@ from yapf.yapflib import py3compat
 from yapf.yapflib import style
 from yapf.yapflib import yapf_api
 
-__version__ = '0.18.0'
+__version__ = '0.20.2'
 
 
 def main(argv):
@@ -99,9 +99,10 @@ def main(argv):
       action='store',
       help=('specify formatting style: either a style name (for example "pep8" '
             'or "google"), or the name of a file with style settings. The '
-            'default is pep8 unless a %s or %s file located in one of the '
-            'parent directories of the source file (or current directory for '
-            'stdin)' % (style.LOCAL_STYLE, style.SETUP_CONFIG)))
+            'default is pep8 unless a %s or %s file located in the same '
+            'directory as the source or one of its parent directories '
+            '(for stdin, the current directory is used).' %
+            (style.LOCAL_STYLE, style.SETUP_CONFIG)))
   parser.add_argument(
       '--style-help',
       action='store_true',
@@ -132,8 +133,12 @@ def main(argv):
     print('yapf {}'.format(__version__))
     return 0
 
+  style_config = args.style
+
   if args.style_help:
-    style.SetGlobalStyle(style.CreateStyleFromConfig(args.style))
+    if style_config is None and not args.no_local_style:
+      style_config = file_resources.GetDefaultStyleForDir(os.getcwd())
+    style.SetGlobalStyle(style.CreateStyleFromConfig(style_config))
     print('[style]')
     for option, docstring in sorted(style.Help().items()):
       for line in docstring.splitlines():
@@ -154,6 +159,8 @@ def main(argv):
 
     original_source = []
     while True:
+      if sys.stdin.closed:
+        break
       try:
         # Use 'raw_input' instead of 'sys.stdin.read', because otherwise the
         # user will need to hit 'Ctrl-D' more than once if they're inputting
@@ -163,7 +170,6 @@ def main(argv):
       except EOFError:
         break
 
-    style_config = args.style
     if style_config is None and not args.no_local_style:
       style_config = file_resources.GetDefaultStyleForDir(os.getcwd())
 
@@ -201,7 +207,7 @@ def FormatFiles(filenames,
                 no_local_style=False,
                 in_place=False,
                 print_diff=False,
-                verify=True,
+                verify=False,
                 parallel=False,
                 verbose=False):
   """Format a list of files.
@@ -251,13 +257,13 @@ def _FormatFile(filename,
                 no_local_style=False,
                 in_place=False,
                 print_diff=False,
-                verify=True,
+                verify=False,
                 verbose=False):
   if verbose:
     print('Reformatting %s' % filename)
   if style_config is None and not no_local_style:
-    style_config = (
-        file_resources.GetDefaultStyleForDir(os.path.dirname(filename)))
+    style_config = file_resources.GetDefaultStyleForDir(
+        os.path.dirname(filename))
   try:
     reformatted_code, encoding, has_change = yapf_api.FormatFile(
         filename,
