@@ -1,4 +1,4 @@
-# Copyright 2015-2016 Google Inc. All Rights Reserved.
+# Copyright 2015 Google Inc. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -140,8 +140,8 @@ class _BlankLineCalculator(pytree_visitor.PyTreeVisitor):
       if not self.last_was_decorator:
         self._SetNumNewlines(node.children[index].children[0], _ONE_BLANK_LINE)
       index += 1
-    if (index and node.children[index].lineno - 1 ==
-        node.children[index - 1].children[0].lineno):
+    if (index and node.children[index].lineno -
+        1 == node.children[index - 1].children[0].lineno):
       self._SetNumNewlines(node.children[index], _NO_BLANK_LINES)
     else:
       if self.last_comment_lineno + 1 == node.children[index].lineno:
