@@ -1,4 +1,4 @@
-# Copyright 2015-2017 Google Inc. All Rights Reserved.
+# Copyright 2015 Google Inc. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -80,28 +80,31 @@ class _SubtypeAssigner(pytree_visitor.PyTreeVisitor):
 
     if not comp_for and dict_maker:
       last_was_colon = False
+      unpacking = False
       for child in node.children:
-        if dict_maker:
-          if pytree_utils.NodeName(child) == 'DOUBLESTAR':
+        if pytree_utils.NodeName(child) == 'DOUBLESTAR':
+          _AppendFirstLeafTokenSubtype(child,
+                                       format_token.Subtype.KWARGS_STAR_STAR)
+        if last_was_colon:
+          if style.Get('INDENT_DICTIONARY_VALUE'):
+            _InsertPseudoParentheses(child)
+          else:
             _AppendFirstLeafTokenSubtype(child,
-                                         format_token.Subtype.KWARGS_STAR_STAR)
-          if last_was_colon:
-            if style.Get('INDENT_DICTIONARY_VALUE'):
-              _InsertPseudoParentheses(child)
-            else:
-              _AppendFirstLeafTokenSubtype(
-                  child, format_token.Subtype.DICTIONARY_VALUE)
-          elif (
-              child is not None and
-              (isinstance(child, pytree.Node) or
-               (not child.value.startswith('#') and child.value not in '{:,'))):
-            # Mark the first leaf of a key entry as a DICTIONARY_KEY. We
-            # normally want to split before them if the dictionary cannot exist
-            # on a single line.
+                                         format_token.Subtype.DICTIONARY_VALUE)
+        elif (isinstance(child, pytree.Node) or
+              (not child.value.startswith('#') and child.value not in '{:,')):
+          # Mark the first leaf of a key entry as a DICTIONARY_KEY. We
+          # normally want to split before them if the dictionary cannot exist
+          # on a single line.
+          if not unpacking or _GetFirstLeafNode(child).value == '**':
             _AppendFirstLeafTokenSubtype(child,
                                          format_token.Subtype.DICTIONARY_KEY)
-            _AppendSubtypeRec(child, format_token.Subtype.DICTIONARY_KEY_PART)
+          _AppendSubtypeRec(child, format_token.Subtype.DICTIONARY_KEY_PART)
         last_was_colon = pytree_utils.NodeName(child) == 'COLON'
+        if pytree_utils.NodeName(child) == 'DOUBLESTAR':
+          unpacking = True
+        elif last_was_colon:
+          unpacking = False
 
   def Visit_expr_stmt(self, node):  # pylint: disable=invalid-name
     # expr_stmt ::= testlist_star_expr (augassign (yield_expr|testlist)
@@ -150,6 +153,7 @@ class _SubtypeAssigner(pytree_visitor.PyTreeVisitor):
       self.Visit(child)
       if isinstance(child, pytree.Leaf) and child.value == '*':
         _AppendTokenSubtype(child, format_token.Subtype.UNARY_OPERATOR)
+        _AppendTokenSubtype(child, format_token.Subtype.VARARGS_STAR)
 
   def Visit_expr(self, node):  # pylint: disable=invalid-name
     # expr ::= xor_expr ('|' xor_expr)*
@@ -303,6 +307,12 @@ class _SubtypeAssigner(pytree_visitor.PyTreeVisitor):
   def Visit_comp_for(self, node):  # pylint: disable=invalid-name
     # comp_for ::= 'for' exprlist 'in' testlist_safe [comp_iter]
     _AppendSubtypeRec(node, format_token.Subtype.COMP_FOR)
+    # Mark the previous node as COMP_EXPR unless this is a nested comprehension
+    # as these will have the outer comprehension as their previous node.
+    attr = pytree_utils.GetNodeAnnotation(node.parent,
+                                          pytree_utils.Annotation.SUBTYPE)
+    if not attr or format_token.Subtype.COMP_FOR not in attr:
+      _AppendSubtypeRec(node.parent.children[0], format_token.Subtype.COMP_EXPR)
     self.DefaultNodeVisit(node)
 
   def Visit_comp_if(self, node):  # pylint: disable=invalid-name
