@@ -1,4 +1,4 @@
-# Copyright 2015-2017 Google Inc. All Rights Reserved.
+# Copyright 2015 Google Inc. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -271,8 +271,9 @@ def _SpaceRequiredBetween(left, right):
     # A typed argument should have a space after the colon.
     return True
   if left.is_string:
-    if (rval == '=' and format_token.Subtype.DEFAULT_OR_NAMED_ASSIGN_ARG_LIST in
-        right.subtypes):
+    if (rval == '=' and
+        format_token.Subtype.DEFAULT_OR_NAMED_ASSIGN_ARG_LIST in right.subtypes
+       ):
       # If there is a type hint, then we don't want to add a space between the
       # equal sign and the hint.
       return False
@@ -281,7 +282,7 @@ def _SpaceRequiredBetween(left, right):
       # or dot should have a space after it.
       return True
   if left.is_binary_op and lval != '**' and _IsUnaryOperator(right):
-    # Space between the binary opertor and the unary operator.
+    # Space between the binary operator and the unary operator.
     return True
   if left.is_keyword and _IsUnaryOperator(right):
     # Handle things like "not -3 < x".
@@ -317,13 +318,13 @@ def _SpaceRequiredBetween(left, right):
     return False
   if left.is_keyword and rval == '.' or lval == '.' and right.is_keyword:
     # Add space between keywords and dots.
-    return True
+    return lval != 'None'
   if lval == '.' or rval == '.':
     # Don't place spaces between dots.
     return False
   if ((lval == '(' and rval == ')') or (lval == '[' and rval == ']') or
       (lval == '{' and rval == '}')):
-    # Empty objects shouldn't be separted by spaces.
+    # Empty objects shouldn't be separated by spaces.
     return False
   if (lval in pytree_utils.OPENING_BRACKETS and
       rval in pytree_utils.OPENING_BRACKETS):
