@@ -1,4 +1,4 @@
-# Copyright 2016-2017 Google Inc. All Rights Reserved.
+# Copyright 2016 Google Inc. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -53,15 +53,11 @@ def _():
       (Gauge(
           metric='aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa',
           group_by=group_by + ['metric:process_name'],
-          metric_filter={
-              'metric:process_name': process_name_re
-          }),
+          metric_filter={'metric:process_name': process_name_re}),
        Gauge(
            metric='bbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbb',
            group_by=group_by + ['metric:process_name'],
-           metric_filter={
-               'metric:process_name': process_name_re
-           }))
+           metric_filter={'metric:process_name': process_name_re}))
       | expr.Join(
           left_name='start', left_default=0, right_name='end', right_default=0)
       | m.Point(
@@ -286,43 +282,23 @@ checkpoint_files = gfile.Glob(
     self.assertCodeEqual(code, reformatter.Reformat(uwlines))
 
   def testB36806207(self):
-    unformatted_code = textwrap.dedent("""\
-        def _():
-          linearity_data = [[row] for row in [
-              "%.1f mm" % (np.mean(linearity_values["pos_error"]) * 1000.0),
-              "%.1f mm" % (np.max(linearity_values["pos_error"]) * 1000.0),
-              "%.1f mm" % (np.mean(linearity_values["pos_error_chunk_mean"]) * 1000.0),
-              "%.1f mm" % (np.max(linearity_values["pos_error_chunk_max"]) * 1000.0),
-              "%.1f deg" % math.degrees(np.mean(linearity_values["rot_noise"])),
-              "%.1f deg" % math.degrees(np.max(linearity_values["rot_noise"])),
-              "%.1f deg" % math.degrees(np.mean(linearity_values["rot_drift"])),
-              "%.1f deg" % math.degrees(np.max(linearity_values["rot_drift"])),
-              "%.1f%%" % (np.max(linearity_values["pos_discontinuity"]) * 100.0),
-              "%.1f%%" % (np.max(linearity_values["rot_discontinuity"]) * 100.0)
-          ]]
-        """)
-    expected_code = textwrap.dedent("""\
-        def _():
-          linearity_data = [
-              [row]
-              for row in [
-                  "%.1f mm" % (np.mean(linearity_values["pos_error"]) * 1000.0),
-                  "%.1f mm" % (np.max(linearity_values["pos_error"]) * 1000.0),
-                  "%.1f mm" % (
-                      np.mean(linearity_values["pos_error_chunk_mean"]) * 1000.0),
-                  "%.1f mm" % (
-                      np.max(linearity_values["pos_error_chunk_max"]) * 1000.0),
-                  "%.1f deg" % math.degrees(np.mean(linearity_values["rot_noise"])),
-                  "%.1f deg" % math.degrees(np.max(linearity_values["rot_noise"])),
-                  "%.1f deg" % math.degrees(np.mean(linearity_values["rot_drift"])),
-                  "%.1f deg" % math.degrees(np.max(linearity_values["rot_drift"])),
-                  "%.1f%%" % (np.max(linearity_values["pos_discontinuity"]) * 100.0),
-                  "%.1f%%" % (np.max(linearity_values["rot_discontinuity"]) * 100.0)
-              ]
-          ]
-        """)
-    uwlines = yapf_test_helper.ParseAndUnwrap(unformatted_code)
-    self.assertEqual(expected_code, reformatter.Reformat(uwlines))
+    code = """\
+def _():
+  linearity_data = [[row] for row in [
+      "%.1f mm" % (np.mean(linearity_values["pos_error"]) * 1000.0),
+      "%.1f mm" % (np.max(linearity_values["pos_error"]) * 1000.0),
+      "%.1f mm" % (np.mean(linearity_values["pos_error_chunk_mean"]) * 1000.0),
+      "%.1f mm" % (np.max(linearity_values["pos_error_chunk_max"]) * 1000.0),
+      "%.1f deg" % math.degrees(np.mean(linearity_values["rot_noise"])),
+      "%.1f deg" % math.degrees(np.max(linearity_values["rot_noise"])),
+      "%.1f deg" % math.degrees(np.mean(linearity_values["rot_drift"])),
+      "%.1f deg" % math.degrees(np.max(linearity_values["rot_drift"])),
+      "%.1f%%" % (np.max(linearity_values["pos_discontinuity"]) * 100.0),
+      "%.1f%%" % (np.max(linearity_values["rot_discontinuity"]) * 100.0)
+  ]]
+"""
+    uwlines = yapf_test_helper.ParseAndUnwrap(code)
+    self.assertCodeEqual(code, reformatter.Reformat(uwlines))
 
   def testB36215507(self):
     code = textwrap.dedent("""\
@@ -1761,6 +1737,28 @@ dddddddddddddddddd().eeeeeeeeeeeeeeeeeeeee().fffffffffffffffff().ggggggggggggggg
     uwlines = yapf_test_helper.ParseAndUnwrap(unformatted_code)
     self.assertCodeEqual(expected_formatted_code, reformatter.Reformat(uwlines))
 
+  def testB67935687(self):
+    code = textwrap.dedent("""\
+        Fetch(
+            Raw('monarch.BorgTask', '/union/row_operator_action_delay'),
+            {'borg_user': self.borg_user})
+    """)
+    uwlines = yapf_test_helper.ParseAndUnwrap(code)
+    self.assertCodeEqual(code, reformatter.Reformat(uwlines))
+
+    unformatted_code = textwrap.dedent("""\
+        shelf_renderer.expand_text = text.translate_to_unicode(
+            expand_text % {
+                'creator': creator
+            })
+        """)
+    expected_formatted_code = textwrap.dedent("""\
+        shelf_renderer.expand_text = text.translate_to_unicode(
+            expand_text % {'creator': creator})
+        """)
+    uwlines = yapf_test_helper.ParseAndUnwrap(unformatted_code)
+    self.assertCodeEqual(expected_formatted_code, reformatter.Reformat(uwlines))
+
 
 if __name__ == '__main__':
   unittest.main()
